"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getHandleSubscriptionAuthorization = void 0;
const limes_1 = require("limes");
const getHandleSubscriptionAuthorization = function ({ identityProviders, issuerForAnonymousTokens }) {
    const limes = new limes_1.Limes({ identityProviders });
    return async (context) => {
        var _a, _b, _c, _d, _e;
        let clientMetadata;
        const token = ((_a = context.extra.request.headers.token) !== null && _a !== void 0 ? _a : (_b = context.connectionParams) === null || _b === void 0 ? void 0 : _b.token);
        const xAnonymousId = ((_c = context.extra.request.headers['x-anonymous-id']) !== null && _c !== void 0 ? _c : (_d = context.connectionParams) === null || _d === void 0 ? void 0 : _d['x-anonymous-id']);
        const remoteAddress = (_e = context.extra.request.socket.remoteAddress) !== null && _e !== void 0 ? _e : '0.0.0.0';
        if (!token) {
            const payload = {
                [`${issuerForAnonymousTokens}/is-anonymous`]: true
            };
            let subject = 'anonymous';
            if (xAnonymousId) {
                subject += `-${xAnonymousId}`;
            }
            const anonymousToken = limes_1.Limes.issueUntrustedToken({
                issuer: issuerForAnonymousTokens,
                subject,
                payload
            });
            clientMetadata = {
                token: anonymousToken.token,
                user: {
                    id: anonymousToken.decodedToken.sub,
                    claims: anonymousToken.decodedToken
                },
                ip: remoteAddress
            };
        }
        else {
            const claims = await limes.verifyToken({ token });
            clientMetadata = {
                token,
                user: {
                    id: claims.sub,
                    claims
                },
                ip: remoteAddress
            };
        }
        return { clientMetadata };
    };
};
exports.getHandleSubscriptionAuthorization = getHandleSubscriptionAuthorization;
//# sourceMappingURL=getHandleSubscriptionAuthorization.js.map