"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getV2 = void 0;
const apollo_server_express_1 = require("apollo-server-express");
const apollo_server_core_1 = require("apollo-server-core");
const ClientMetadata_1 = require("../../../common/utils/http/ClientMetadata");
const getApiBase_1 = require("../../base/getApiBase");
const getAuthenticationMiddleware_1 = require("../../base/getAuthenticationMiddleware");
const getHandleSubscriptionAuthorization_1 = require("./getHandleSubscriptionAuthorization");
const getSchema_1 = require("./getSchema");
const graphql_ws_1 = require("graphql-ws");
const graphql_1 = require("graphql");
const withLogMetadata_1 = require("../../../common/utils/logging/withLogMetadata");
const ws_1 = __importDefault(require("ws"));
const flaschenpost_1 = require("flaschenpost");
const errors = __importStar(require("../../../common/errors"));
const logger = flaschenpost_1.flaschenpost.getLogger();
const getV2 = async function ({ corsOrigin, application, identityProviders, handleCommand, observeDomainEvents, observeNotifications, queryView, enableIntegratedClient, webSocketEndpoint }) {
    if (!webSocketEndpoint && (observeDomainEvents || observeNotifications)) {
        throw new errors.ParameterInvalid('If observe domain events or observe notifications is enabled, a websocket endpoint must be given.');
    }
    const api = await (0, getApiBase_1.getApiBase)({
        request: {
            headers: {
                cors: { origin: corsOrigin },
                // If the GraphQL playground is enabled, CSP must be disabled for the apollo cdn to work.
                csp: !enableIntegratedClient
            },
            body: { parser: { sizeLimit: 100000 } },
            query: { parser: { useJson: false } }
        },
        response: {
            headers: { cache: false }
        }
    });
    api.use((0, flaschenpost_1.getMiddleware)());
    const authenticationMiddleware = await (0, getAuthenticationMiddleware_1.getAuthenticationMiddleware)({
        identityProviders
    });
    api.use(authenticationMiddleware);
    const { schema, publishDomainEvent } = await (0, getSchema_1.getSchema)({
        application,
        handleCommand,
        observeDomainEvents,
        observeNotifications,
        queryView
    });
    const schemaValidationErrors = (0, graphql_1.validateSchema)(schema);
    if (schemaValidationErrors.length > 0) {
        for (const error of schemaValidationErrors) {
            logger.fatal('GraphQL schema validation failed.', (0, withLogMetadata_1.withLogMetadata)('api', 'graphql', { error }));
        }
        throw new errors.GraphQlError('GraphQL schema validation failed.');
    }
    const graphqlServer = new apollo_server_express_1.ApolloServer({
        schema,
        context({ req }) {
            return { clientMetadata: new ClientMetadata_1.ClientMetadata({ req }) };
        },
        introspection: true,
        plugins: enableIntegratedClient ?
            [
                // eslint-disable-next-line new-cap
                (0, apollo_server_core_1.ApolloServerPluginLandingPageGraphQLPlayground)({
                    endpoint: webSocketEndpoint
                })
            ] :
            []
    });
    await graphqlServer.start();
    graphqlServer.applyMiddleware({
        app: api,
        path: '/',
        cors: false
    });
    const initializeGraphQlOnServer = async ({ server }) => {
        if (!observeDomainEvents && !observeNotifications) {
            return;
        }
        const handleSubscriptionAuthorization = (0, getHandleSubscriptionAuthorization_1.getHandleSubscriptionAuthorization)({
            identityProviders,
            issuerForAnonymousTokens: 'https://token.invalid'
        });
        const graphqlSubscriptionServer = (0, graphql_ws_1.makeServer)({
            schema,
            async context(ctx) {
                return await handleSubscriptionAuthorization(ctx);
            }
        });
        const wsServer = new ws_1.default.Server({
            server,
            path: webSocketEndpoint
        });
        // The following snippet is more or less directly taken from the examples
        // of [graphql-ws](https://github.com/enisdenjo/graphql-ws).
        wsServer.on('connection', (socket, request) => {
            const closed = graphqlSubscriptionServer.opened({
                protocol: socket.protocol,
                async send(data) {
                    await new Promise((resolve, reject) => {
                        socket.send(data, (err) => {
                            if (err) {
                                reject(err);
                                return;
                            }
                            resolve();
                        });
                    });
                },
                close(code, reason) {
                    socket.close(code, reason);
                },
                onMessage(cb) {
                    socket.on('message', async (event) => {
                        try {
                            // eslint-disable-next-line @typescript-eslint/no-base-to-string
                            await cb(event.toString());
                        }
                        catch (ex) {
                            socket.close(1011, ex.message);
                        }
                    });
                }
            }, { request });
            socket.once('close', async (code, reason) => {
                await closed(code, reason);
            });
        });
    };
    return { api, publishDomainEvent, initializeGraphQlOnServer };
};
exports.getV2 = getV2;
//# sourceMappingURL=index.js.map