"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.landingPage = void 0;
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const landingPage = {
    description: 'Serves the landing page',
    path: '',
    request: {},
    response: {
        statusCodes: [200]
    },
    async getHandler() {
        const absoluteAssetsDirectory = path_1.default.join(__dirname, '..', '..', '..', '..', 'assets');
        const absoluteLandingPageFile = path_1.default.join(absoluteAssetsDirectory, 'landingPage.html');
        const absoluteWolkenkitLogoFile = path_1.default.join(absoluteAssetsDirectory, 'logo.svg');
        const absoluteFaviconFile = path_1.default.join(absoluteAssetsDirectory, 'favicon.png');
        const [landingPageContentRaw, wolkenkitLogoBase64, faviconBase64] = await Promise.all([
            await fs_1.default.promises.readFile(absoluteLandingPageFile, 'utf-8'),
            await fs_1.default.promises.readFile(absoluteWolkenkitLogoFile, 'base64'),
            await fs_1.default.promises.readFile(absoluteFaviconFile, 'base64')
        ]);
        const landingPageContent = landingPageContentRaw.
            replace('<wolkenkitLogoSvgSrc>', `data:image/svg+xml;charset=utf-8;base64,${wolkenkitLogoBase64}`).
            replace('<wolkenkitFaviconPngSrc>', `data:image/png;base64,${faviconBase64}`);
        return async function (req, res) {
            res.status(200).send(landingPageContent);
        };
    }
};
exports.landingPage = landingPage;
//# sourceMappingURL=landingPage.js.map