"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getApi = void 0;
const http_1 = require("../../../../apis/awaitItem/http");
const getCommandWithMetadataSchema_1 = require("../../../../common/schemas/getCommandWithMetadataSchema");
const get_cors_origin_1 = require("get-cors-origin");
const http_2 = require("../../../../apis/handleCommandWithMetadata/http");
const http_3 = require("../../../../apis/landingPage/http");
const validate_value_1 = require("validate-value");
const validateCommandWithMetadata_1 = require("../../../../common/validators/validateCommandWithMetadata");
const express_1 = __importDefault(require("express"));
const getApi = async function ({ configuration, application, priorityQueueStore, newCommandSubscriber, newCommandPubSubChannel, onReceiveCommand, onCancelCommand }) {
    const commandWithMetadataParser = new validate_value_1.Parser((0, getCommandWithMetadataSchema_1.getCommandWithMetadataSchema)());
    const { api: landingPageApi } = await (0, http_3.getApi)();
    const { api: handleCommandApi } = await (0, http_2.getApi)({
        corsOrigin: (0, get_cors_origin_1.getCorsOrigin)(configuration.handleCommandCorsOrigin),
        onReceiveCommand,
        onCancelCommand,
        application
    });
    const { api: awaitCommandWithMetadataApi } = await (0, http_1.getApi)({
        corsOrigin: (0, get_cors_origin_1.getCorsOrigin)(configuration.awaitCommandCorsOrigin),
        priorityQueueStore,
        newItemSubscriber: newCommandSubscriber,
        newItemSubscriberChannel: newCommandPubSubChannel,
        validateOutgoingItem({ item }) {
            commandWithMetadataParser.parse(item, { valueName: 'command' }).unwrapOrThrow();
            (0, validateCommandWithMetadata_1.validateCommandWithMetadata)({ application, command: item });
        }
    });
    const api = (0, express_1.default)();
    api.use(landingPageApi);
    api.use('/handle-command', handleCommandApi);
    api.use('/await-command', awaitCommandWithMetadataApi);
    return { api };
};
exports.getApi = getApi;
//# sourceMappingURL=getApi.js.map