"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.withTransaction = void 0;
const mongodb_1 = require("mongodb");
const withTransaction = async function ({ client, fn }) {
    let result;
    await client.withSession({
        defaultTransactionOptions: {
            readPreference: new mongodb_1.ReadPreference('primary'),
            readConcern: mongodb_1.ReadConcern.fromOptions({ level: 'local' }),
            // eslint-disable-next-line id-length
            writeConcern: { w: 'majority' }
        }
    }, async (session) => {
        await session.withTransaction(async () => {
            result = await fn({ session });
        });
    });
    return result;
};
exports.withTransaction = withTransaction;
//# sourceMappingURL=withTransaction.js.map